@@ -14,23 +14,25 @@ class QFile;
 class QUrl;
 class QSqlQuery;
 
-struct BacklinkHit {
-    BacklinkHit(QString markdown, QString text) noexcept
+struct LinkHit {
+    explicit LinkHit(QString markdown = "", QString text = "") noexcept
         : markdown(std::move(markdown)), text(std::move(text)) {}
 
     bool isEmpty() const noexcept { return markdown.isEmpty() && text.isEmpty(); }
 
     // Add operator== for comparison
-    bool operator==(const BacklinkHit &other) const {
+    bool operator==(const LinkHit &other) const {
         return markdown == other.markdown && text == other.text;
     }
 
+    friend QDebug operator<<(QDebug dbg, const LinkHit &hit);
+
     QString markdown;
     QString text;
 };
 
-// Add hash function for BacklinkHit
-inline uint qHash(const BacklinkHit &hit, uint seed = 0) {
+// Add hash function for LinkHit
+inline uint qHash(const LinkHit &hit, uint seed = 0) {
     return qHash(hit.markdown, seed) ^ qHash(hit.text, seed);
 }
 
@@ -115,7 +117,8 @@ class Note {
 
     static QString getFullFilePathForFile(const QString &fileName);
 
-    QString getFilePathRelativeToNote(const Note &note) const;
+    QString getFilePathRelativeToNote(
+        const Note &note, const QString &connectionName = QStringLiteral("memory")) const;
 
     static int storeDirtyNotesToDisk(Note &currentNote, bool *currentNoteChanged = nullptr,
                                      bool *noteWasRenamed = nullptr,
@@ -180,7 +183,7 @@ class Note {
 
     QUrl fullNoteFileUrl() const;
 
-    QString fullNoteFilePath() const;
+    QString fullNoteFilePath(const QString &connectionName = QStringLiteral("memory")) const;
 
     QString fullNoteFileDirPath() const;
 
@@ -219,7 +222,7 @@ class Note {
 
     QString fileBaseName(bool withFullName = false);
 
-    NoteSubFolder getNoteSubFolder() const;
+    NoteSubFolder getNoteSubFolder(const QString &connectionName = QStringLiteral("memory")) const;
 
     void setNoteSubFolder(const NoteSubFolder &noteSubFolder);
 
@@ -237,7 +240,8 @@ class Note {
 
     bool isInCurrentNoteSubFolder() const;
 
-    QString relativeNoteFilePath(QString separator = QString()) const;
+    QString relativeNoteFilePath(QString separator = QString(),
+                                 const QString &connectionName = QStringLiteral("memory")) const;
 
     QString relativeNoteSubFolderPath() const;
 
@@ -270,9 +274,9 @@ class Note {
 
     static QVector<int> fetchAllIds(int limit = -1, int offset = -1);
 
-    QVector<int> findLinkedNoteIds() const;
+    QVector<int> findBacklinkedNoteIds() const;
 
-    bool handleNoteMoving(const Note &oldNote);
+    bool handleNoteMoving(Note oldNote);
 
     static QString createNoteHeader(const QString &name);
 
@@ -377,13 +381,15 @@ class Note {
 
     static QString removeNameSearchPrefix(QString searchTerm);
 
-    QStringList getHeadingList();
-
     static bool applyIgnoredNotesSetting(QStringList &fileNames);
 
     QSet<Note> findBacklinks() const;
 
-    QHash<Note, QSet<BacklinkHit>> findReverseLinkNotes();
+    QHash<Note, QSet<LinkHit>> findLinkedNotes(
+        QVector<Note> noteList = QVector<Note>(),
+        const QString &connectionName = QStringLiteral("memory"));
+
+    QHash<Note, QSet<LinkHit>> findReverseLinkNotes();
 
    protected:
     int _id;
@@ -405,7 +411,8 @@ class Note {
     int _shareId;
     unsigned int _sharePermissions;
     bool _hasDirtyData;
-    QHash<Note, QSet<BacklinkHit>> _backlinkNoteHash;
+    QHash<Note, QSet<LinkHit>> _backlinkNoteHash;
+    QHash<Note, QSet<LinkHit>> _linkedNoteHash;
 
     static QRegularExpression getEncryptedNoteTextRegularExpression();
     QString getEncryptedNoteText() const;
@@ -416,12 +423,18 @@ class Note {
 
     void restoreCreatedDate();
 
-    static BacklinkHit findAndReturnBacklinkHit(const QString &text, const QString &pattern);
-    static QSet<BacklinkHit> findAndReturnBacklinkHit(const QString &text,
-                                                      const QRegularExpression &regex);
+    static LinkHit findAndReturnLinkHit(const QString &text, const QString &pattern);
+    static QSet<LinkHit> findAndReturnLinkHits(const QString &text,
+                                               const QRegularExpression &regex);
 
     void addTextToBacklinkNoteHashIfFound(const Note &note, const QString &pattern);
+    void addTextToLinkedNoteHashIfFound(const Note &note, const QString &noteText,
+                                        const QString &pattern);
     void addTextToBacklinkNoteHashIfFound(const Note &note, const QRegularExpression &pattern);
+    void addTextToLinkedNoteHashIfFound(const Note &note, const QString &noteText,
+                                        const QRegularExpression &pattern);
+    bool handleLinkedNotesAfterMoving(const QHash<Note, QSet<LinkHit>> &linkedNoteHits);
+    bool handleBacklinkedNotesAfterMoving(const Note &oldNote, const QVector<int> &noteIdList);
 };
 
 inline uint qHash(const Note &note, uint seed) { return qHash(note.getId(), seed); }
