@@ -1300,6 +1300,22 @@ bool Utils::Misc::isNoteEditingAllowed() {
     return SettingsService().value(QStringLiteral("allowNoteEditing"), true).toBool();
 }
 
+/**
+ * Returns if "hideIconsInMenus" is turned on
+ *
+ * @return
+ */
+bool Utils::Misc::areMenuIconsHidden() {
+#ifdef Q_OS_MAC
+    // hide icons in menus by default on macOS
+    const bool defaultValue = true;
+#else
+    const bool defaultValue = false;
+#endif
+
+    return SettingsService().value(QStringLiteral("hideIconsInMenus"), defaultValue).toBool();
+}
+
 /**
  * Returns if "useInternalExportStyling" is turned on
  *
@@ -2656,3 +2672,22 @@ int Utils::Misc::getPreviewRefreshDebounceTime() {
 int Utils::Misc::getMaximumNoteFileSize() {
     return SettingsService().value(QStringLiteral("maxNoteFileSize"), 1048576).toInt();
 }
+
+/**
+ * Percent encode each individual segment of a file path
+ * @param filePath
+ * @return
+ */
+QString Utils::Misc::encodeFilePath(const QString &filePath) {
+    // Split the path into segments to preserve the directory separators
+    QStringList segments = filePath.split('/');
+
+    // URL encode each segment individually
+    for (int i = 0; i < segments.size(); ++i) {
+        // Use QUrl::toPercentEncoding to properly encode special characters
+        segments[i] = QUrl::toPercentEncoding(segments[i], "/");
+    }
+
+    // Join the segments back together with forward slashes
+    return segments.join('/');
+}
